#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__K__1___TwoPRep_S__0__G__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+840)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+852)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+861)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+864)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(stack[((hsi*3+861)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*6+864)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+890)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+905)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+911)*1+lsi)*1]), &(stack[((hsi*6+905)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+921)*1+lsi)*1]), &(stack[((hsi*10+911)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*6+905)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+852)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*3+861)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+936)*1+lsi)*1]), &(stack[((hsi*6+864)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(stack[((hsi*3+861)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+946)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*10+936)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*6+864)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+961)*1+lsi)*1]), &(stack[((hsi*15+890)*1+lsi)*1]), &(stack[((hsi*15+946)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+982)*1+lsi)*1]), &(stack[((hsi*15+921)*1+lsi)*1]), &(stack[((hsi*15+890)*1+lsi)*1]), &(stack[((hsi*10+911)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1003)*1+lsi)*1]), &(stack[((hsi*21+982)*1+lsi)*1]), &(stack[((hsi*21+961)*1+lsi)*1]), &(stack[((hsi*15+921)*1+lsi)*1]), &(stack[((hsi*15+890)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+840)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*3+861)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1031)*1+lsi)*1]), &(stack[((hsi*10+936)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*6+864)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1046)*1+lsi)*1]), &(stack[((hsi*15+946)*1+lsi)*1]), &(stack[((hsi*15+1031)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*10+936)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1067)*1+lsi)*1]), &(stack[((hsi*21+961)*1+lsi)*1]), &(stack[((hsi*21+1046)*1+lsi)*1]), &(stack[((hsi*15+890)*1+lsi)*1]), &(stack[((hsi*15+946)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1095)*1+lsi)*1]), &(stack[((hsi*28+1003)*1+lsi)*1]), &(stack[((hsi*28+1067)*1+lsi)*1]), &(stack[((hsi*21+982)*1+lsi)*1]), &(stack[((hsi*21+961)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+861)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+864)*1+lsi)*1]), &(stack[((hsi*3+861)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*6+864)*1+lsi)*1]), &(stack[((hsi*6+905)*1+lsi)*1]), &(stack[((hsi*3+861)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+890)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*10+911)*1+lsi)*1]), &(stack[((hsi*6+864)*1+lsi)*1]), &(stack[((hsi*6+905)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1131)*1+lsi)*1]), &(stack[((hsi*15+890)*1+lsi)*1]), &(stack[((hsi*15+921)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*10+911)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1152)*1+lsi)*1]), &(stack[((hsi*21+1131)*1+lsi)*1]), &(stack[((hsi*21+982)*1+lsi)*1]), &(stack[((hsi*15+890)*1+lsi)*1]), &(stack[((hsi*15+921)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+890)*1+lsi)*1]), &(stack[((hsi*28+1152)*1+lsi)*1]), &(stack[((hsi*28+1003)*1+lsi)*1]), &(stack[((hsi*21+1131)*1+lsi)*1]), &(stack[((hsi*21+982)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1180)*1+lsi)*1]), &(stack[((hsi*36+890)*1+lsi)*1]), &(stack[((hsi*36+1095)*1+lsi)*1]), &(stack[((hsi*28+1003)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+0)*1+lsi)*1]),&(stack[((hsi*108+1180)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+982)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+926)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*6+982)*1+lsi)*1]), &(stack[((hsi*3+852)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+988)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*10+926)*1+lsi)*1]), &(stack[((hsi*6+855)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1131)*1+lsi)*1]), &(stack[((hsi*15+1031)*1+lsi)*1]), &(stack[((hsi*15+988)*1+lsi)*1]), &(stack[((hsi*10+936)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+852)*1+lsi)*1]), &(stack[((hsi*21+1046)*1+lsi)*1]), &(stack[((hsi*21+1131)*1+lsi)*1]), &(stack[((hsi*15+946)*1+lsi)*1]), &(stack[((hsi*15+1031)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1288)*1+lsi)*1]), &(stack[((hsi*28+1067)*1+lsi)*1]), &(stack[((hsi*28+852)*1+lsi)*1]), &(stack[((hsi*21+961)*1+lsi)*1]), &(stack[((hsi*21+1046)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+936)*1+lsi)*1]), &(stack[((hsi*36+1095)*1+lsi)*1]), &(stack[((hsi*36+1288)*1+lsi)*1]), &(stack[((hsi*28+1003)*1+lsi)*1]), &(stack[((hsi*28+1067)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1324)*1+lsi)*1]), &(stack[((hsi*36+890)*1+lsi)*1]), &(stack[((hsi*36+1095)*1+lsi)*1]), &(stack[((hsi*28+1152)*1+lsi)*1]), &(stack[((hsi*28+1003)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1369)*1+lsi)*1]), &(stack[((hsi*45+1324)*1+lsi)*1]), &(stack[((hsi*45+936)*1+lsi)*1]), &(stack[((hsi*36+1095)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+108)*1+lsi)*1]),&(stack[((hsi*135+1369)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1003)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1152)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(stack[((hsi*3+1003)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1006)*1+lsi)*1]), &(stack[((hsi*6+982)*1+lsi)*1]), &(stack[((hsi*6+1152)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1016)*1+lsi)*1]), &(stack[((hsi*10+926)*1+lsi)*1]), &(stack[((hsi*10+1006)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*6+982)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1158)*1+lsi)*1]), &(stack[((hsi*15+988)*1+lsi)*1]), &(stack[((hsi*15+1016)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*10+926)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1504)*1+lsi)*1]), &(stack[((hsi*21+1131)*1+lsi)*1]), &(stack[((hsi*21+1158)*1+lsi)*1]), &(stack[((hsi*15+1031)*1+lsi)*1]), &(stack[((hsi*15+988)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1532)*1+lsi)*1]), &(stack[((hsi*28+852)*1+lsi)*1]), &(stack[((hsi*28+1504)*1+lsi)*1]), &(stack[((hsi*21+1046)*1+lsi)*1]), &(stack[((hsi*21+1131)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1568)*1+lsi)*1]), &(stack[((hsi*36+1288)*1+lsi)*1]), &(stack[((hsi*36+1532)*1+lsi)*1]), &(stack[((hsi*28+1067)*1+lsi)*1]), &(stack[((hsi*28+852)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1031)*1+lsi)*1]), &(stack[((hsi*45+936)*1+lsi)*1]), &(stack[((hsi*45+1568)*1+lsi)*1]), &(stack[((hsi*36+1095)*1+lsi)*1]), &(stack[((hsi*36+1288)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1613)*1+lsi)*1]), &(stack[((hsi*45+1324)*1+lsi)*1]), &(stack[((hsi*45+936)*1+lsi)*1]), &(stack[((hsi*36+890)*1+lsi)*1]), &(stack[((hsi*36+1095)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+1668)*1+lsi)*1]), &(stack[((hsi*55+1613)*1+lsi)*1]), &(stack[((hsi*55+1031)*1+lsi)*1]), &(stack[((hsi*45+936)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+243)*1+lsi)*1]),&(stack[((hsi*165+1668)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+840)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*3+1003)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*6+1152)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(stack[((hsi*3+1003)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1086)*1+lsi)*1]), &(stack[((hsi*10+1006)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*6+982)*1+lsi)*1]), &(stack[((hsi*6+1152)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+890)*1+lsi)*1]), &(stack[((hsi*15+1016)*1+lsi)*1]), &(stack[((hsi*15+1086)*1+lsi)*1]), &(stack[((hsi*10+926)*1+lsi)*1]), &(stack[((hsi*10+1006)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1101)*1+lsi)*1]), &(stack[((hsi*21+1158)*1+lsi)*1]), &(stack[((hsi*21+890)*1+lsi)*1]), &(stack[((hsi*15+988)*1+lsi)*1]), &(stack[((hsi*15+1016)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1833)*1+lsi)*1]), &(stack[((hsi*28+1504)*1+lsi)*1]), &(stack[((hsi*28+1101)*1+lsi)*1]), &(stack[((hsi*21+1131)*1+lsi)*1]), &(stack[((hsi*21+1158)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1869)*1+lsi)*1]), &(stack[((hsi*36+1532)*1+lsi)*1]), &(stack[((hsi*36+1833)*1+lsi)*1]), &(stack[((hsi*28+852)*1+lsi)*1]), &(stack[((hsi*28+1504)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1914)*1+lsi)*1]), &(stack[((hsi*45+1568)*1+lsi)*1]), &(stack[((hsi*45+1869)*1+lsi)*1]), &(stack[((hsi*36+1288)*1+lsi)*1]), &(stack[((hsi*36+1532)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1969)*1+lsi)*1]), &(stack[((hsi*55+1031)*1+lsi)*1]), &(stack[((hsi*55+1914)*1+lsi)*1]), &(stack[((hsi*45+936)*1+lsi)*1]), &(stack[((hsi*45+1568)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2035)*1+lsi)*1]), &(stack[((hsi*55+1613)*1+lsi)*1]), &(stack[((hsi*55+1031)*1+lsi)*1]), &(stack[((hsi*45+1324)*1+lsi)*1]), &(stack[((hsi*45+936)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+2101)*1+lsi)*1]), &(stack[((hsi*66+2035)*1+lsi)*1]), &(stack[((hsi*66+1969)*1+lsi)*1]), &(stack[((hsi*55+1031)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+408)*1+lsi)*1]),&(stack[((hsi*198+2101)*1+lsi)*1]),198);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+911)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]), &(stack[((hsi*3+843)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+917)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]), &(stack[((hsi*6+911)*1+lsi)*1]), &(stack[((hsi*3+1003)*1+lsi)*1]), &(stack[((hsi*3+840)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1288)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]), &(stack[((hsi*10+917)*1+lsi)*1]), &(stack[((hsi*6+1152)*1+lsi)*1]), &(stack[((hsi*6+846)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+911)*1+lsi)*1]), &(stack[((hsi*15+1086)*1+lsi)*1]), &(stack[((hsi*15+1288)*1+lsi)*1]), &(stack[((hsi*10+1006)*1+lsi)*1]), &(stack[((hsi*10+880)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+932)*1+lsi)*1]), &(stack[((hsi*21+890)*1+lsi)*1]), &(stack[((hsi*21+911)*1+lsi)*1]), &(stack[((hsi*15+1016)*1+lsi)*1]), &(stack[((hsi*15+1086)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1288)*1+lsi)*1]), &(stack[((hsi*28+1101)*1+lsi)*1]), &(stack[((hsi*28+932)*1+lsi)*1]), &(stack[((hsi*21+1158)*1+lsi)*1]), &(stack[((hsi*21+890)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1324)*1+lsi)*1]), &(stack[((hsi*36+1833)*1+lsi)*1]), &(stack[((hsi*36+1288)*1+lsi)*1]), &(stack[((hsi*28+1504)*1+lsi)*1]), &(stack[((hsi*28+1101)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+840)*1+lsi)*1]), &(stack[((hsi*45+1869)*1+lsi)*1]), &(stack[((hsi*45+1324)*1+lsi)*1]), &(stack[((hsi*36+1532)*1+lsi)*1]), &(stack[((hsi*36+1833)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+895)*1+lsi)*1]), &(stack[((hsi*55+1914)*1+lsi)*1]), &(stack[((hsi*55+840)*1+lsi)*1]), &(stack[((hsi*45+1568)*1+lsi)*1]), &(stack[((hsi*45+1869)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+1504)*1+lsi)*1]), &(stack[((hsi*66+1969)*1+lsi)*1]), &(stack[((hsi*66+895)*1+lsi)*1]), &(stack[((hsi*55+1031)*1+lsi)*1]), &(stack[((hsi*55+1914)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+840)*1+lsi)*1]), &(stack[((hsi*66+2035)*1+lsi)*1]), &(stack[((hsi*66+1969)*1+lsi)*1]), &(stack[((hsi*55+1613)*1+lsi)*1]), &(stack[((hsi*55+1031)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*234+918)*1+lsi)*1]), &(stack[((hsi*78+840)*1+lsi)*1]), &(stack[((hsi*78+1504)*1+lsi)*1]), &(stack[((hsi*66+1969)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*234+606)*1+lsi)*1]),&(stack[((hsi*234+918)*1+lsi)*1]),234);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 840 */
}

#ifdef __cplusplus
};
#endif
